==> serna-free_4.3.0.20110221.orig.tar.gz: serna-free-4.3.0.20110221/serna/core/DocBuilders.h <==
// 
// Copyright(c) 2009 Syntext, Inc. All Rights Reserved.
// Contact: info@syntext.com, http://www.syntext.com
// 
// This file is part of Syntext Serna XML Editor.
// 
// COMMERCIAL USAGE
// Licensees holding valid Syntext Serna commercial licenses may use this file
// in accordance with the Syntext Serna Commercial License Agreement provided
// with the software, or, alternatively, in accorance with the terms contained
// in a written agreement between you and Syntext, Inc.
// 
// GNU GENERAL PUBLIC LICENSE USAGE
// Alternatively, this file may be used under the terms of the GNU General 
// Public License versions 2.0 or 3.0 as published by the Free Software 
// Foundation and appearing in the file LICENSE.GPL included in the packaging 
// of this file. In addition, as a special exception, Syntext, Inc. gives you
// certain additional rights, which are described in the Syntext, Inc. GPL 
// Exception for Syntext Serna Free Edition, included in the file 
// GPL_EXCEPTION.txt in this package.
// 
// You should have received a copy of appropriate licenses along with this 
// package. If not, see <http://www.syntext.com/legal/>. If you are unsure
// which license is appropriate for your use, please contact the sales 
// department at sales@syntext.com.
// 
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// 
#ifndef CORE_DOC_BUILDERS_H_
#define CORE_DOC_BUILDERS_H_

#include "docview/SernaDoc.h"

class EmptyDocumentBuilder : public DocBuilder {
public:
    virtual ~EmptyDocumentBuilder() {};

    virtual void    buildActions(Sui::ActionDispatcher* dispatcher,
                                  Sui::ActionSet* actionSet) const;
    virtual void    buildInterface(Common::PropertyNode* property) const;
};

class StructDocumentBuilder : public DocBuilder {
public:
    virtual ~StructDocumentBuilder() {};

    virtual void    buildActions(Sui::ActionDispatcher* dispatcher,
                                  Sui::ActionSet* actionSet) const;
    virtual void    buildInterface(Common::PropertyNode* property) const;
};

class PlainDocumentBuilder : public DocBuilder {
public:
    virtual ~PlainDocumentBuilder() {};

    virtual void    buildActions(Sui::ActionDispatcher* dispatcher,
                                  Sui::ActionSet* actionSet) const;
    virtual void    buildInterface(Common::PropertyNode* property) const;
};

#endif // CORE_DOC_BUILDERS_H_

==> serna-free_4.4.0.20111005.orig.tar.gz: serna-free-4.4.0.20111005/serna/core/DocBuilders.h <==
// 
// Copyright(c) 2009 Syntext, Inc. All Rights Reserved.
// Contact: info@syntext.com, http://www.syntext.com
// 
// This file is part of Syntext Serna XML Editor.
// 
// COMMERCIAL USAGE
// Licensees holding valid Syntext Serna commercial licenses may use this file
// in accordance with the Syntext Serna Commercial License Agreement provided
// with the software, or, alternatively, in accorance with the terms contained
// in a written agreement between you and Syntext, Inc.
// 
// GNU GENERAL PUBLIC LICENSE USAGE
// Alternatively, this file may be used under the terms of the GNU General 
// Public License versions 2.0 or 3.0 as published by the Free Software 
// Foundation and appearing in the file LICENSE.GPL included in the packaging 
// of this file. In addition, as a special exception, Syntext, Inc. gives you
// certain additional rights, which are described in the Syntext, Inc. GPL 
// Exception for Syntext Serna Free Edition, included in the file 
// GPL_EXCEPTION.txt in this package.
// 
// You should have received a copy of appropriate licenses along with this 
// package. If not, see <http://www.syntext.com/legal/>. If you are unsure
// which license is appropriate for your use, please contact the sales 
// department at sales@syntext.com.
// 
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// 
#ifndef CORE_DOC_BUILDERS_H_
#define CORE_DOC_BUILDERS_H_

#include "docview/SernaDoc.h"
#include "docview/DocBuilder.h"

class EmptyDocumentBuilder : public DocBuilder {
public:
    virtual ~EmptyDocumentBuilder() {};

    virtual void    buildActions(Sui::ActionDispatcher* dispatcher,
                                  Sui::ActionSet* actionSet);
    virtual Common::PropertyNode* loadSui();
};

class StructDocumentBuilder : public DocBuilder {
public:
    virtual ~StructDocumentBuilder() {};

    virtual void    buildActions(Sui::ActionDispatcher* dispatcher,
                                  Sui::ActionSet* actionSet);
    virtual Common::PropertyNode* loadSui();
};

class PlainDocumentBuilder : public DocBuilder {
public:
    virtual ~PlainDocumentBuilder() {};

    virtual void    buildActions(Sui::ActionDispatcher* dispatcher,
                                  Sui::ActionSet* actionSet);
    virtual Common::PropertyNode* loadSui();
};

#endif // CORE_DOC_BUILDERS_H_
